@@ -1,4 +1,4 @@
-# pylint: disable-msg=C0103
+# pylint: disable=C0103
 """test pb with exceptions and old/new style classes"""
 
 __revision__ = 1
@@ -10,7 +10,7 @@ class BofException:
     """mouais"""
     
 class NewException(object):
-    """non !"""
+    """non si py < 2.5 !"""
 
 def fonctionOk():
     """raise"""
@@ -31,5 +31,7 @@ def fonctionBof2():
 def fonctionNew2():
     """raise"""
     raise NewException
-    
 
+def fonctionNotImplemented():
+    """raise"""
+    raise NotImplemented, 'hop'
