@@ -12,10 +12,10 @@ class Aaaa:
     
     def meth2(self):
         """hehehe"""
-        return 'Yo'
+        return 'Yo', self
 
 class Bbbb(Aaaa):
     """yeah"""
     def meth1(self):
         """hehehe bis"""
-        return "yeah"
+        return "yeah", self
