@@ -1,4 +1,4 @@
-# pylint: disable-msg=R0903
+# pylint: disable=R0903
 """test unused argument
 """
 
@@ -22,14 +22,22 @@ class AAAA:
         """called by the registry when the vobject has been selected.
         """
         return cls
-    
+
     def using_inner_function(self, etype, size=1):
         """return a fake result set for a particular entity type"""
         rset = AAAA([('A',)]*size, '%s X' % etype,
                     description=[(etype,)]*size)
         def inner(row, col=0, etype=etype, req=self, rset=rset):
             """inner using all its argument"""
-            # pylint: disable-msg = E1103
+            # pylint: disable = E1103
             return req.vreg.etype_class(etype)(req, rset, row, col)
-        # pylint: disable-msg = W0201
+        # pylint: disable = W0201
         rset.get_entity = inner
+
+class BBBB:
+    """dummy class"""
+
+    def __init__(self, arg):
+        """Constructor with an extra parameter. Should raise a warning"""
+        self.spam = 1
+
